/*
 * Copyright 1999-2004 The Apache Software Foundation.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/* $Id$ */

package org.apache.fop.render.afp;

import org.apache.fop.render.afp.tools.BinaryUtils;

/**
 * This class encapsulates the font atributes that need to be included
 * in the AFP data stream. This class does not assist in converting the
 * font attributes to AFP code pages and character set values.
 * 
 * @author Pete Townsend <a href="mailto:pete@townsend.uk.com"/>
 */
public class AFPFontAttributes {

	/**
	 * The font reference byte
	 */
	private byte _fontReference;
	
	/**
	 * The font family name
	 */
	private String _fontFamily;
	
	/**
	 * The font weight
	 */
	private String _fontWeight;
	
	/**
	 * The font style
	 */
	private String _fontStyle;
	
	/**
	 * The point size
	 */
	private int _pointSize;

	/**
	 * Constructor for the AFPFontAttributes
	 * @param fontFamily the font family name
	 * @param fontWeight the font weight
	 * @param fontStyle the font style
	 * @param pointSize the point size
	 */
	public AFPFontAttributes(
		
		String fontFamily,
		String fontWeight,
		String fontStyle,
		int pointSize) {

		_fontFamily = fontFamily;
		_fontWeight = fontWeight;
		_fontStyle = fontStyle;
		_pointSize = pointSize;

	}
	/**
	 * @return the FontFamily attribute
	 */
	public String getFontFamily() {
		return _fontFamily;
	}

	/**
	 * @return the FontKey attribute
	 */
	public String getFontKey() {
	
		return _fontFamily + _fontWeight + _fontStyle + _pointSize;

	}

	/**
	 * @return the font style attribute
	 */
	public String getFontStyle() {
		return _fontStyle;
	}

	/**
	 * @return the font weight attribute
	 */
	public String getFontWeight() {
		return _fontWeight;
	}

	/**
	 * @return the point size attribute
	 */
	public int getPointSize() {
		return _pointSize;
	}

	/**
	 * @return the FontReference attribute
	 */
	public byte getFontReference() {
		return _fontReference;
	}

	/**
	 * Sets the FontReference attribute
	 * @param FontReference the FontReference to set
	 */
	public void setFontReference(int fontReference) {
		
		String id = String.valueOf(fontReference);
		_fontReference = BinaryUtils.convert(id)[0];
		
	}

}
