/*
 * Copyright 1999-2004 The Apache Software Foundation.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/* $Id$ */

package org.apache.fop.render.afp;

/**
 * AFP only supports very basic colours and this object provides a simple
 * bean for the colour attributes.
 * 
 * @author Pete Townsend <a href="mailto:pete@townsend.uk.com"/>
 */
public class AFPFontColor {

	/**
	 * Red value.
	 */
	private float _red = 0;

	/**
	 * Green value.
	 */
	private float _green = 0;

	/**
	 * Blue value.
	 */
	private float _blue = 0;

	/**
	 * Constructor for the AFPColor Object
	 */
	public AFPFontColor(float red, float green, float blue) {

		_red = red;
		_green = green;
		_blue = blue;

	}

	/**
	 * Returns the blue attribute
	 * @return float
	 */
	public float getBlue() {
		return _blue;
	}

	/**
	 * Returns the green attribute
	 * @return float
	 */
	public float getGreen() {
		return _green;
	}

	/**
	 * Returns the red attribute
	 * @return float
	 */
	public float getRed() {
		return _red;
	}

	/**
	 * Sets the blue attribute
	 * @param blue The blue value to set
	 */
	public void setBlue(float blue) {
		_blue = blue;
	}

	/**
	 * Sets the green attribute
	 * @param green The green value to set
	 */
	public void setGeen(float green) {
		_green = green;
	}

	/**
	 * Sets the red attribute
	 * @param red The red value to set
	 */
	public void setRed(float red) {
		_red = red;
	}

	/**
	 * Checks whether this object is equal to the parameter passed 
	 * as an argument. If the parameter is an instance of AFPColor
	 * then the value are compared, otherwise the generalized equals
	 * method is invoked on the parent class.
	 * 
	 * @param obj the object to compare
	 * @return boolean true if the object is equal
	 */
	public boolean equals(Object obj) {

		if (obj instanceof AFPFontColor) {
			AFPFontColor c = (AFPFontColor) obj;
			if (c.getRed() == _red
				&& c.getGreen() == _green
				&& c.getBlue() == _blue) {
				return true;
			} else {
				return false;
			}
		} else {
			return super.equals(obj);
		}

	}

}
