package org.apache.fop.render.afp.extensions;

import org.apache.fop.apps.FOPException;
import org.apache.fop.fo.Property;
import org.apache.fop.fo.PropertyList;
import org.apache.fop.fo.StringProperty;

/**
 * This class extends the org.apache.fop.fo.StringProperty.Maker inner class
 * in order to provide a static property maker. The object faciliates 
 * extraction of attributes from formatted objects based on the static list
 * as defined in the AFPElementMapping implementation.
 * @author Pete Townsend
 * @version 1.0 (24/11/2003)
 */
public class AFPAttribute extends StringProperty.Maker {

	/**
	 * The attribute property.
	 */
	private Property _property;

	/**
	 * Constructor for the AFPAttribute.
	 * @param name The attribute name
	 */
	protected AFPAttribute(String name) {
		super(name);
		_property = null;
	}

	/**
	 * Overide the make method to return the property object
	 * @return property The property object.
	 */
	public Property make(PropertyList propertyList) throws FOPException {
		if (_property == null) {
			_property = make(propertyList, "", propertyList.getParentFObj());
		}
		return _property;
	}

	/**
	 * Static maker method, to obtain an instance of the Maker class
	 * @return maker The property maker object.
	 */
	public static Property.Maker maker(String propName) {
		return new AFPAttribute(propName);
	}

}