package org.apache.fop.render.afp.extensions;

import java.util.Collection;

import org.apache.fop.apps.FOPException;
import org.apache.fop.extensions.ExtensionObj;
import org.apache.fop.fo.FObj;
import org.apache.fop.fo.PropertyList;

/**
 * This class extends the org.apache.fop.extensions.ExtensionObj class. The 
 * object faciliates extraction of elements from formatted objects based on 
 * the static list as defined in the AFPElementMapping implementation.
 * @author Pete Townsend
 * @version 1.0 (24/11/2003)
 */
public class AFPElement extends ExtensionObj {

	/**
	 * The name of the element
	 */
	private String _name = null;
	
	/**
	 * The static Maker class responsible for building the AFPElement objects.
	 */
	public static class Maker extends FObj.Maker {
		
		/**
		 * The name of the element
		 */
		private String _name;

		/**
		 * Implementation of the make method, responsible for building
		 * AFPElement objects for the element name specified on construction.
		 */
		public FObj make(
			FObj parent,
			PropertyList propertyList,
			String systemId,
			int line,
			int column)
			throws FOPException {
			return new AFPElement(parent, propertyList, systemId, line, column, _name);
		}

		/**
		 * Constructor for the Maker object
		 * @param name The element name
		 */
		public Maker(String name) {
			
			_name = name;
			
		}
	} // End of the maker inner class.

	/**
	 * Constructor for the AFPElement
	 * @param parent The parent object
	 * @param propertyList The property list
	 * @param systemId The system id
	 * @param int The line number
	 * @param int The column number
	 * @param name The element name
	 */
	public AFPElement(
		FObj parent,
		PropertyList propertyList,
		String systemId,
		int line,
		int column,
		String name) {
		super(parent, propertyList, systemId, line, column);
		_name = name;

	}

	/**
	 * Static maker method to build the maker object.
	 * @param name The element name
	 */
	public static Maker maker(String name) {
		return new Maker(name);
	}

	/**
	 * Getter method for the name of the element (including the namespace)
	 * @return name The element name, including namespace.
	 */
	public String getName() {
		return "afp:" + _name;
	}
	
	/**
	 * Getter method for the child elements of this node
	 * @return collection The collection of children
	 */
	public Collection getChildren() {
		
		return super.children;
		
	}

}
