package org.apache.fop.render.afp.extensions;

import java.util.HashMap;

import org.apache.fop.fo.StandardElementMapping;
import org.apache.fop.fo.TreeBuilder;

/**
 * AFPElementMapping object provides the ability to extract information
 * from the formatted object that reside in our own namespace. This is used
 * for custom AFP extensions not supported by the FO schema. Examples include
 * adding comments to the AFP datastream, overlays or indexing a document using 
 * the tag logical element structured field. * 
 * This extends the standard element mapping:
 * @see org.apache.fop.fo.StandardElementMapping
 * 
 * @author Russ Hodey
 * @version 1.0 (20/11/2003)
 * @version 1.1 (24/11/2003): Pete Townsend - Fixed problem with extracting attribute data (
 * changed by rjh to cater for overlays.
 * Changed by rjh to cater for the dynamic placing of overlays, using IPS's.
 */
public class AFPElementMapping extends StandardElementMapping{

	/**
	 * The namespace used for AFP extensions
	 */
	public static final String URI = "http://org.apache.fop/extensions/afp";
	
	/**
	 * Static HashMap of Elements to extract (with their associated makers).
	 */
	private static HashMap _afpElements = null;
	
	/**
	 * Static HashMap of Attributes to extract (with their associated makers).
	 */
	private static HashMap _afpAttributes = null;

	/**
	 * Private static synchronized method to set up the element and atribute
	 * HashMaps, this defines what elements and attributes are extracted.
	 */
    private static synchronized void setupExt() {
    	
        if(_afpElements == null) {
            _afpElements = new HashMap();    
            _afpElements.put("page-group", AFPElement.maker("page-group"));
            _afpElements.put("end-page-group", AFPElement.maker("end-page-group"));
            _afpElements.put("tag-logical-element", AFPElement.maker("tag-logical-element"));
            _afpElements.put("attribute", AFPElement.maker("attribute"));
        	 _afpElements.put("overlay", AFPElement.maker("overlay"));
        	 _afpElements.put("dynamic-overlay", AFPElement.maker("dynamic-overlay"));
        }
        
        if(_afpAttributes == null) {
            _afpAttributes = new HashMap();    
            _afpAttributes.put("name", AFPAttribute.maker("name"));
            _afpAttributes.put("value", AFPAttribute.maker("value"));
            _afpAttributes.put("comment", AFPAttribute.maker("comment"));
            _afpAttributes.put("x-axis", AFPAttribute.maker("x-axis"));
         	_afpAttributes.put("y-axis", AFPAttribute.maker("y-axis"));
         	_afpAttributes.put("orientation", AFPAttribute.maker("orientation")); 
        }
        
    }
    
    /** 
     * Override the addToBuilder method so that the builder is setup 
     * with the emelemt mappings and the property list.
     * @param builder The builder to which the mappings are added
     */
    public void addToBuilder(TreeBuilder builder) {
    	
        setupExt();
        builder.addMapping(URI, _afpElements);
		builder.addPropertyList(URI, _afpAttributes);
       
    }
  
}
