/*
 * Copyright 1999-2004 The Apache Software Foundation.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/* $Id$ */

package org.apache.fop.render.afp.fonts;

/**
 * The CharacterSet object provides a simple wrapper for the the 
 * afp character set identifier. The key is the key to the character 
 * set based on it's attributes (normal/bold and normal/italics). The 
 * character set attribute is the actual AFP character set reference.
 * <p/>
 * @author Pete Townsend <a href="mailto:pete@townsend.uk.com"/>
 */
public class CharacterSet {
	
	/**
	 * The chacater set key
	 */
	private String _characterSetKey;
	
	/**
	 * The AFP character set reference
	 */
	private byte[] _characterSet;
	
	/**
	 * Constructs a CharacterSet object from the ket and character set data.
	 * @param characterSetKey the character set key
	 * @param characterSet the AFP character set reference
	 */	
	public CharacterSet(String characterSetKey, byte[] characterSet) {
		
		_characterSetKey = characterSetKey;
		_characterSet = characterSet;
		
	}

	/**
	 * @return the AFP character set reference
	 */
	public byte[] getCharacterSet() {
		return _characterSet;
	}

	/**
	 * @return the character set key
	 */
	public String getCharacterSetKey() {
		return _characterSetKey;
	}

}
