/*
 * Copyright 1999-2004 The Apache Software Foundation.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/* $Id$ */

package org.apache.fop.render.afp.fonts;

import java.util.HashMap;
/**
 * A singleton factory for obtaining a collection of fonts for a particular
 * dpi ("dots per inch") resolution.
 *
 * @author Pete Townsend <a href="mailto:pete@townsend.uk.com"/>
 */
public class FontFactory {

	/** The font factory instance */
	private static FontFactory _fontFactory = null;

	/** The map of font collections */
	private HashMap _fontCollections = null;

	/** 
	 * Private constructor for the FontFactory
	 */
	private FontFactory() {
		_fontCollections = new HashMap();
	}

	/**
	 * @return an instance of the FontFactory class
	 */
	public static synchronized FontFactory getInstance() {

		if (_fontFactory == null) {
			_fontFactory = new FontFactory();
		}
		return _fontFactory;

	}

	/**
	 * Getter for the collection of fonts fo rthe specified resolution
	 * @param dpi the resolution
	 * @return the collection of fonts
	 */
	public FontCollection getFontCollection(int dpi) {

		FontCollection fc =
			(FontCollection) _fontCollections.get(String.valueOf(dpi));
			
		if (fc == null) {	
			fc = new FontCollection(dpi);
			_fontCollections.put(String.valueOf(dpi), fc);
		}
		return fc;

	}

}
