/*
 * Copyright 1999-2004 The Apache Software Foundation.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/* $Id$ */

package org.apache.fop.render.afp.fonts;

import java.util.Collection;
import java.util.Iterator;

import org.apache.fop.apps.FOPException;
import org.apache.fop.layout.FontInfo;

/**
 * A helper class to set up the {@link org.apache.fop.layout.FontInfo} object
 * with the apropriate font metrics.
 * <p/>
 * @author Pete Townsend <a href="mailto:pete@townsend.uk.com"/>
 */
public class FontSetup {
	
	/** The font prefix */
	private static final String PREFIX = "F";
	
	/**
     * Static method to set up the font info object, this will process
     * the afp-fonts.xml file and obtain the font metics from the installed
     * fonts.  
     * @param fontInfo the font object to set up
     */
    public static void setup(int dpi, FontInfo fontInfo) throws FOPException {
    	
		int count = 0;
		FontFactory ff = FontFactory.getInstance();
		FontCollection fontCollection = ff.getFontCollection(dpi);

		Collection c = fontCollection.getFonts();

		Iterator i = c.iterator();
		while (i.hasNext()) {

			Font font = (Font) i.next();

			Collection p = font.getFontMetricCollection();
			Iterator psi = p.iterator();
			while (psi.hasNext()) {
				
				count++;

				FontMetrics ps = (FontMetrics) psi.next();

				fontInfo.addMetrics(PREFIX + count, ps);
				fontInfo.addFontProperties(
					PREFIX + count, 
					font.getFontFamily(),
					ps.getStyle(),
					ps.getWeight());
					
			}

		}	
   
    }

}
