/*
 * Copyright 1999-2004 The Apache Software Foundation.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/* $Id$ */

package org.apache.fop.render.afp.fonts;

import java.util.HashMap;

/**
 * The PointSize object contains the collection of character set font 
 * mappings for the specified point size.
 * <p/>
 * @author Pete Townsend <a href="mailto:pete@townsend.uk.com"/>
 */
public class PointSize {

	/**
	 * The point size attribute of the font
	 */
	private int _pointsize = 0;

	/**
	 * The collection of character sets
	 */
	private HashMap _charactersetMap;

	/**
	 * Constructs a PointSize object for the specified size.
	 * @param pointsize the point size
	 */
	public PointSize(int pointsize) {

		_pointsize = pointsize;
		_charactersetMap = new HashMap(4);

	}

	/**
	 * Add a character set for the specified weight and style.
	 * @param weight the weight (i.e. normal/bold)
	 * @param style the style (i.e. normal/italics)
	 * @param characterSet the character set data
	 */
	public void addCharacterSet(String weight, String style, byte[] characterSet) {

		CharacterSet cs = new CharacterSet(getCharacterSetKey(weight, style), characterSet);
		_charactersetMap.put(cs.getCharacterSetKey(), cs);

	}

	/**
	 * @return the point size of this object
	 */
	public int getPointSize() {
		return _pointsize;
	}

	/**
	 * Gets the character set for the specified weight and style.
	 * @param weight the weight (i.e. normal/bold)
	 * @param style the style (i.e. normal/italics)
	 * @return the character set object
	 */
	public CharacterSet getCharacterSet(String weight, String style) {
		return (CharacterSet) _charactersetMap.get(getCharacterSetKey(weight, style));
	}

	/**
	 * Getter for the key to the character set data.
	 * @param weight the weight (i.e. normal/bold)
	 * @param style the style (i.e. normal/italics)
	 * @return the key to the character set data
	 */
	private String getCharacterSetKey(String weight, String style) {
		return weight + "-" + style;
	}

}
