/*
 * Copyright 1999-2004 The Apache Software Foundation.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/* $Id$ */

package org.apache.fop.render.afp.modca;

import java.io.IOException;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * This is the base class for all data stream objects. Page objects are 
 * responsible for building and generating the binary datastream in an
 * AFP format.
 * 
 * @author Pete Townsend <a href="mailto:pete@townsend.uk.com"/>
 */
public abstract class AFPObject {

	/**
	 * Static logging instance
	 */
	protected static final Log LOGGER =
		LogFactory.getLog("org.apache.fop.render.afp.modca");

	/**
	 * DataStream objects must implement the getDataStream()
	 * method to return a byte array of the AFP datastream.
	 * @return byte[] The AFP data stream
	 * @throws java.io.IOException
	 */
	public abstract byte[] getDataStream() throws IOException;

}
