/*
 * Copyright 1999-2004 The Apache Software Foundation.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/* $Id$ */

package org.apache.fop.render.afp.modca;

import java.io.IOException;
import java.io.UnsupportedEncodingException;

/**
  * The End Named Page Group (ENG) structured field terminates a page group that was
  * initiated by a Begin Named Page Group structured field.
  * 
  * Note :This object will be used to represent an ENG
  * structured field. It is necessary as you can't end 
  * a PageGroup because you don't know where the group
  * will end (as this is controlled by the tags in the FO).
  * <p>
  * Copyright &copy; 2004 Legal &amp; General.
  *
  * @author Pete Townsend <a href="mailto:pete@townsend.uk.com"/>
  */
public class EndPageGroup extends AFPObject {

	/**
	 * The group id of the ENG stored in bytes
	 */
	private byte[] _byteGroupId;

	public EndPageGroup(String groupId) {

		LOGGER.debug("A ENG is being created for group: " + groupId);
		if (groupId.length() != 8) {
			throw new IllegalArgumentException(
				"EndPageGroup name must be 8 characters long: " + groupId);
		}
		try {

			_byteGroupId = groupId.getBytes(AFPConstants.EBCIDIC_ENCODING);

		} catch (UnsupportedEncodingException usee) {

			_byteGroupId = groupId.getBytes();
			LOGGER.warn(
				"Constructor:: UnsupportedEncodingException translating the name "
					+ groupId);

		}
	}

	/* (non-Javadoc)
	 * @see org.apache.fop.render.afp.modca.AFPObject#getDataStream()
	 */
	public byte[] getDataStream() throws IOException {
		byte[] data = new byte[17];

		data[0] = 0x5A; // Structured field identifier
		data[1] = 0x00; // Length byte 1
		data[2] = 0x10; // Length byte 2
		data[3] = (byte) 0xD3; // Structured field id byte 1
		data[4] = (byte) 0xA9; // Structured field id byte 2
		data[5] = (byte) 0xAD; // Structured field id byte 3
		data[6] = 0x00; // Flags
		data[7] = 0x00; // Reserved
		data[8] = 0x00; // Reserved

		for (int i = 0; i < _byteGroupId.length; i++) {

			data[9 + i] = _byteGroupId[i];

		}
		return data;
	}

}
