/*
 * Copyright 1999-2004 The Apache Software Foundation.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/* $Id$ */

package org.apache.fop.render.afp.modca;

import org.apache.fop.render.afp.tools.BinaryUtils;

/**
 * @author Pete Townsend <a href="mailto:pete@townsend.uk.com"/>
 */
public class Overlay extends AFPObject{

	private byte [] _overlayName = null;
	private ActiveEnvironmentGroup _activeEnvironmentGroup = null;
	
	/* (non-Javadoc)
	 * @see org.apache.fop.render.afp.modca.AFPObject#getDataStream()
	 */
	public byte[] getDataStream() {
		return null;
	}
	
	public Overlay(String name) {

		if (name.length() != 8) {
			throw new IllegalArgumentException(
				"Page name must be 8 characters long: " + name);
		}

		_overlayName = BinaryUtils.convert(name);

		// The overlay should share the aeg with the page
		//_activeEnvironmentGroup = aeg;

	}
	
	/**
	 * Helper method to return the start of the Overlay
	 * as a byte array.
	 * 
	 * Note:what is the size of the overlayname????
	 * 
	 * @param name of the Overlay used on the mainframe.
	 * @return byte[].
	 */
	
	private static final byte[] getStart(String name) {

		byte[] data = new byte[17];

		data[0] = 0x5A; // Structured field identifier
		data[1] = 0x00; // Length byte 1
		data[2] = 0x10; // Length byte 2
		data[3] = (byte) 0xD3; // Structured field id byte 1
		data[4] = (byte) 0xA8; // Structured field id byte 2
		data[5] = (byte) 0xDF; // Structured field id byte 3
		data[6] = 0x00; // Flags
		data[7] = 0x00; // Reserved
		data[8] = 0x00; // Reserved

		for (int i = 0; i < name.length(); i++) {

			data[9 + i] = (byte) name.charAt(i);

		}

		return data;

	}
	/**
	 * Helper method to return the end of the Overlay
	 * as a byte array.
	 * 
	 * Note:what is the size of the overlayname????
	 * 
	 * @param name of the Overlay used on the mainframe.
	 * @return byte[].
	 */
	
	private static final byte[] getEnd(String name) {

		byte[] data = new byte[17];

		data[0] = 0x5A; // Structured field identifier
		data[1] = 0x00; // Length byte 1
		data[2] = 0x10; // Length byte 2
		data[3] = (byte) 0xD3; // Structured field id byte 1
		data[4] = (byte) 0xA9; // Structured field id byte 2
		data[5] = (byte) 0xDF; // Structured field id byte 3
		data[6] = 0x00; // Flags
		data[7] = 0x00; // Reserved
		data[8] = 0x00; // Reserved

		for (int i = 0; i < name.length(); i++) {

			data[9 + i] = (byte) name.charAt(i);

		}

		return data;

	}
	
}
