/*
 * Copyright 1999-2004 The Apache Software Foundation.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/* $Id$ */

package org.apache.fop.render.afp.modca;

import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.util.ArrayList;
import java.util.Iterator;

/**
 * @author Pete Townsend <a href="mailto:pete@townsend.uk.com"/>
 */
public class PageGroup extends AFPObject {

	/**
	 * Static class reference
	 */
	private final static Class CLASS = PageGroup.class;

	/**
	 * Static class name reference
	 */
	private final static String CLASS_NAME = CLASS.getName();

	/**
	 * the name of the page group
	 */

	private String _name;
	/**
	 * the name of the page group, stored in bytes
	 */

	private byte[] _byteName;

	/**
	 * A list of the objects in the page group
	 * Note : at the mo they are only pages though
	 */
	private ArrayList _objects = new ArrayList();

	public PageGroup(String name) {

		if (name.length() != 8) {
			throw new IllegalArgumentException(
				"PageGroup name must be 8 characters long: " + name);
		}
		_name = name;
		try {

			_byteName = name.getBytes(AFPConstants.EBCIDIC_ENCODING);

		} catch (UnsupportedEncodingException usee) {

			_byteName = name.getBytes();
			LOGGER.warn(
				"Constructor:: UnsupportedEncodingException translating the name "
					+ name);

		}
	}

	/* (non-Javadoc)
	 * @see org.apache.fop.render.afp.modca.AFPObject#getDataStream()
	 */
	public byte[] getDataStream() throws IOException {

		ByteArrayOutputStream baos = new ByteArrayOutputStream();

		baos.write(getStart());

		//now get the data for all the objects encapsulated within 
		//the Page Group (Pages)
		Iterator i = _objects.iterator();
		while (i.hasNext()) {

			AFPObject apo = (AFPObject) i.next();
			baos.write(apo.getDataStream());

		}

		return baos.toByteArray();
	}
	
	/**
	 * Adds the page object to the list
	 */
	public void addPage(Page page) {

		_objects.add(page);
	}

	/**
	 * Returns the _name.
	 * @return String
	 */
	public String get_name() {
		return _name;
	}
	private byte[] getStart() {

		byte[] data = new byte[17];

		data[0] = 0x5A; // Structured field identifier
		data[1] = 0x00; // Length byte 1
		data[2] = 0x10; // Length byte 2
		data[3] = (byte) 0xD3; // Structured field id byte 1
		data[4] = (byte) 0xA8; // Structured field id byte 2
		data[5] = (byte) 0xAD; // Structured field id byte 3
		data[6] = 0x00; // Flags
		data[7] = 0x00; // Reserved
		data[8] = 0x00; // Reserved

		for (int i = 0; i < _byteName.length; i++) {

			data[9 + i] = _byteName[i];

		}

		return data;

	}
	
	/**
	 * 
	 */
	public void createPGTLE(String name, String value) {
		
		TagLogicalElement tle = new TagLogicalElement(name, value);
		_objects.add(tle);

	}

}
